/*
Module : IconDlg.cpp
Purpose: Implementation for an MFC class for an Icon Picker dialog
Created: PJN / 25-07-1997
History: PJN / 25-07-1997 Initial Public Release
         PJN / 30-12-2016 1. Updated copyright details.
                          2. Updated the sample apps main icon
                          3. Replaced all occurrences of NULL with nullptr throughout the codebase
                          4. Updated the code to clean compile on VC 2010 to VC 2015. The code now
                          requires VC 2010 at a minimum.
                          5. Reworked the code to use the PickIconDlg Win32 API
         PJN / 27-12-2018 1. Updated copyright details.
                          2. Fixed a number of C++ core guidelines compiler warnings. These changes mean that the code
                          will now only compile on VC 2017 or later.
         PJN / 16-04-2022 1. Updated copyright details.
                          2. Updated the code to use C++ uniform initialization for all variable declarations

Copyright (c) 1997 - 2022 by PJ Naughter (Web: www.naughter.com, Email: pjna@naughter.com)

All rights reserved.

Copyright / Usage Details:

You are allowed to include the source code in any product (commercial, shareware, freeware or otherwise) 
when your product is released in binary form. You are allowed to modify the source code in any way you want 
except you cannot modify the copyright details at the top of each module. If you want to distribute source 
code with your application, then you are only allowed to distribute versions released by the author. This is 
to maintain a single distribution point for the source code. 

*/


//////////////////// Includes /////////////////////////////////////////////////

#include "stdafx.h"
#include "IconDlg.h"
#ifndef _SHLOBJ_H_
#pragma message("To avoid this message, please put ShlObj.h in your pre compiled header (normally stdafx.h)")
#include <ShlObj.h>
#endif //#ifndef _SHLOBJ_H_


//////////////////// Macros / Defines /////////////////////////////////////////

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

#pragma comment(lib, "Shell32.lib")


//////////////////// Implementation ///////////////////////////////////////////

#pragma warning(suppress: 26455)
CIconDialog::CIconDialog(_In_opt_ CWnd* pParent) : m_nIconIndex{0}
{
  if (pParent != nullptr)
    m_hWnd = pParent->GetSafeHwnd();
  else
    m_hWnd = nullptr;

  //Default will be to display icons from shell32 dll
  CStringW wsFilename;
  const UINT nGSD{GetSystemDirectoryW(wsFilename.GetBuffer(_MAX_PATH), _MAX_PATH)};
  wsFilename.ReleaseBuffer();
  if (nGSD)
  {
    m_sFilename += wsFilename;
    m_sFilename += L"\\SHELL32.dll";
  }
}

void CIconDialog::SetIcon(_In_ const CString& sFilename, _In_ int nIndex)
{
  m_sFilename = sFilename;
  m_nIconIndex = nIndex;
}

void CIconDialog::GetIcon(_Inout_ CString& sFilename, _Out_ int& nIconIndex)
{
  sFilename = m_sFilename;
  nIconIndex = m_nIconIndex;
}

int CIconDialog::DoModal()
{
  //Call the PickIconDlg API
  const int nReturn{PickIconDlg(m_hWnd, m_sFilename.GetBufferSetLength(_MAX_PATH), _MAX_PATH, &m_nIconIndex)};
  m_sFilename.ReleaseBuffer();
  return nReturn;
}
